/* project01/main.c 
 * Toggling LED in C using registers by addresses 
 * This program toggles green LED for 0.5 second ON and 0.5 second OFF.
 * The green LED is connected to PTB19.
 * The LEDs are active low ('0' turns ON the LED).
 *
 * This is a slightly modified version of the example code "Program2_1.txt"
 * from the book of Mazidi et. al.: "Freescale ARM Cortex-M Embedded Programming Using C Language"
 * Link: http://www.microdigitaled.com/ARM/Freescale_ARM/Code/Ver1/Chapter2/Program2_1.txt 
 *
 * Cycle count was modified in function DelayMs() since default setting of the CPU clock
 * is 20 MHz in case of Keil MDK5 v5.20 RTE library (see in file system_MKL25Z4.h)
 */

/* System Integration Module System Clock Gating Control Register 5*/
#define SIM_SCGC5   (*((volatile unsigned int*)0x40048038))
/* Port B Pin Control Register 19*/
#define PORTB_PCR19 (*((volatile unsigned int*)0x4004A04C))
/* Port B Data Direction Register */
#define GPIOB_PDDR  (*((volatile unsigned int*)0x400FF054))
/* Port B Data Output Register */
#define GPIOB_PDOR  (*((volatile unsigned int*)0x400FF040))
	
    void delayMs(int n);

int main (void) {  
    SIM_SCGC5 |= 0x400;             /* enable clock to Port B */
    PORTB_PCR19 = 0x100;            /* make PTB19 pin as GPIO (See Table 2-4) */
    GPIOB_PDDR |= 0x80000;          /* make PTB19 as output pin */
    
    while (1) {
        GPIOB_PDOR &= ~0x80000;     /* turn on green LED */
        delayMs(5000);
        GPIOB_PDOR |= 0x80000;      /* turn off green LED */
        delayMs(5000);
    }
}

/* Delay n milliseconds
 * The CPU clock is set to 20.97152 MHz in SystemInit() by default.
 */
void delayMs(int n) {
    int i;
    int j;
    for(i = 0 ; i < n; i++)
        for (j = 0; j < 3500; j++) {}
}
